import math
import matplotlib.pyplot as plt

class matrix_algebra:
    ''' basic matrix algebra such as addition, subtraction, multiplication, matrix inversion, etc. 
    
    Attributes:
    
    
    Actions:
    
    '''
    
    def __init__(self):
        
    
    
    def addition(self, other):
        if
    



# TODO: Fill out this file with information about your package

# HINT: Go back to the object-oriented programming lesson "Putting Code on PyPi" and "Exercise: Upload to PyPi"

# HINT: Here is an example of a setup.py file
# https://packaging.python.org/tutorials/packaging-projects/

from setuptools import setup

setup(name='matrix_algebra11',
      version='0.1.1',
      description='basic matrix algebra',   # basic matrix algebra such as addition, subtraction, multiplication, matrix inversion, etc.
      packages=['matrix_algebra11'],
      zip_safe=False)

